(v1.3.3)=
### 1.3.3 {small}`2018-11-05`

#### Major updates

- a fully distributed preprocessing backend {smaller}`T White and the Laserson Lab`

#### Code design

- {func}`~scanpy.read_10x_h5` and {func}`~scanpy.read_10x_mtx` read Cell Ranger 3.0 outputs {pr}`334` {smaller}`Q Gong`

```{note}
#### Also see changes in anndata 0.6.

- changed default compression to `None` in {meth}`~anndata.AnnData.write_h5ad` to speed up read and write, disk space use is usually less critical
- performance gains in {meth}`~anndata.AnnData.write_h5ad` due to better handling of strings and categories {smaller}`S Rybakov`
```
